<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package StarterBlog
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function starterblog_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'starterblog_body_classes' );


define('starter_blog_THEME_NAME','Starter Blog');
define('starter_blog_THEME_SLUG','starter-blog');
define('starter_blog_THEME_URL','https://fancywp.com/product/starter-blog-pro');
define('starter_blog_DEMO_URL','https://fancywp.com/demo/starter-blog-pro');
define('starter_blog_THEME_AUTHOR_URL','https://fancywp.com');
define('starter_blog_THEME_DOC','https://fancywp.com/wp-tutorials/starter-blog-tutorial/');
define('starter_blog_THEME_REVIEW_URL','https://wordpress.org/support/theme/'.starter_blog_THEME_SLUG.'/reviews/');
define('starter_blog_TEMPLATE_DIR',get_template_directory());
define('starter_blog_TEMPLATE_DIR_URI',get_template_directory_uri());

/**
* display notice 
**/
if(!function_exists('starter_blog_general_admin_notice')){

	function starter_blog_general_admin_notice(){
			 $msg = sprintf('<div data-dismissible="disable-done-notice-forever" class="notice notice-info is-dismissible" >
					<p> %1$s %2$s <span style="color:#dc3232">&#9733;</span><span style="color:#dc3232">&#9733;</span><span style="color:#dc3232">&#9733;</span><span style="color:#dc3232">&#9733;</span><span style="color:#dc3232">&#9733;</span> %3$s <span style="color:red">&hearts;</span>  %4$s <a href=%5$s target="_blank"  style="text-decoration: none; margin-left:10px;" class="button button-primary"> %6$s </a>
					<a href=%7$s target="_blank"  style="text-decoration: none; " class="button button-primary">%8$s</a>
					<a href=%9$s target="_blank"  style="text-decoration: none; " class="button button-primary">%10$s</a>
					<a href=%11$s target="_blank"  style="text-decoration: none;" class="button button-primary">%12$s</a><br /><br />
					<span><strong>%13$s</strong></span>
					<a href="?starter_blog_notice_dismissed" target="_self"  style="text-decoration: none; float: right; background: #ccc; padding: 10px 20px; color: #000;border-radius: 10px" class="thickbox">%14$s</a>
					</p></div>',
					
					esc_html__(' If you like the ','starter-blog'),
					esc_html__(' theme, please leave us a ','starter-blog'),
					esc_html__(' Rating. ','starter-blog'),
					esc_html__(' Huge thanks in advance. Please click here to ','starter-blog'),
					esc_url(starter_blog_THEME_REVIEW_URL),
					esc_html__('Rate and Review!','starter-blog'),				
					esc_url(starter_blog_THEME_URL),
					esc_html__('Buy Starter Blog Pro','starter-blog'),
					esc_url(starter_blog_THEME_DOC),	
					esc_html__('How to make a site with Starter Blog','starter-blog'),
					esc_url(starter_blog_DEMO_URL),	
					esc_html__('Starter Blog Pro Demo','starter-blog'),					
					esc_html__('Install Qubely plugins and import starter packs!', 'starter-blog'),
					esc_html__('Dismiss','starter-blog') );
			 echo wp_kses_post($msg); 
	}
	
}

//show, hide notice, update_option('starter_blog_notice',1);
if ( isset( $_GET['starter_blog_notice_dismissed'] ) ){
	update_option('starter_blog_notice', 8);
}

$starter_blog_notice = get_option('starter_blog_notice', 0);
if($starter_blog_notice != 8){
	add_action('admin_notices', 'starter_blog_general_admin_notice');
}